@@ -1,4 +1,216 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
+<context>
+    <name>MainWindow</name>
+    <message>
+        <location filename="mainwindow.ui" line="14"/>
+        <source>Codecs Installer</source>
+        <translation>Instalátor kodeků</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="27"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Tato aplikace Vám umožní nainstalovat nesvodobné kodeky, které spřístupňují pokročilé funkce videa a audia.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;
+V některých krajinách může byt jejich šíření omezené, je na uživateli, aby dodržoval lokální právné předpisy. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Přebíráte právní zodpovědnost za stažení těchto kodeků?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="44"/>
+        <source>Downloading codecs files</source>
+        <translation>Stahuji kodeky</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="94"/>
+        <source>Cancel any changes then quit</source>
+        <translation>Zrušit všechny změny a ukončit</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="97"/>
+        <location filename="mainwindow.cpp" line="268"/>
+        <source>Cancel</source>
+        <translation>Zrušit</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="104"/>
+        <source>Alt+N</source>
+        <translation>Alt+N</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="117"/>
+        <source>Apply any changes then quit</source>
+        <translation>Uložit všechny změny a ukončit</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="120"/>
+        <source>OK</source>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="175"/>
+        <source>About this application</source>
+        <translation>O této aplikaci</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="178"/>
+        <source>About...</source>
+        <translation>O programu</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="185"/>
+        <source>Alt+B</source>
+        <translation>Alt+B</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="214"/>
+        <source>Display help </source>
+        <translation>Zobrazit nápovědu</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="217"/>
+        <source>Help</source>
+        <translation>Nápověda</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="224"/>
+        <source>Alt+H</source>
+        <translation>Alt+H</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="105"/>
+        <location filename="mainwindow.cpp" line="112"/>
+        <location filename="mainwindow.cpp" line="120"/>
+        <location filename="mainwindow.cpp" line="128"/>
+        <location filename="mainwindow.cpp" line="137"/>
+        <location filename="mainwindow.cpp" line="144"/>
+        <location filename="mainwindow.cpp" line="153"/>
+        <location filename="mainwindow.cpp" line="161"/>
+        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
+        <translation>&lt;b&gt;Spouštím příkaz...&lt;/b&gt;&lt;p&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="108"/>
+        <location filename="mainwindow.cpp" line="124"/>
+        <location filename="mainwindow.cpp" line="131"/>
+        <location filename="mainwindow.cpp" line="140"/>
+        <location filename="mainwindow.cpp" line="146"/>
+        <location filename="mainwindow.cpp" line="157"/>
+        <location filename="mainwindow.cpp" line="164"/>
+        <location filename="mainwindow.cpp" line="193"/>
+        <location filename="mainwindow.cpp" line="246"/>
+        <source>Error</source>
+        <translation>Chyba</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="109"/>
+        <location filename="mainwindow.cpp" line="125"/>
+        <location filename="mainwindow.cpp" line="141"/>
+        <location filename="mainwindow.cpp" line="158"/>
+        <source>Cannot connect to the download site</source>
+        <translation>Nelze se připojit k stránce</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="115"/>
+        <location filename="mainwindow.cpp" line="132"/>
+        <location filename="mainwindow.cpp" line="147"/>
+        <location filename="mainwindow.cpp" line="165"/>
+        <source>Error downloading %1</source>
+        <translation>Chyba stahování %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="170"/>
+        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
+        <translation>&lt;b&gt;Stahování dokončeno.&lt;/b&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="189"/>
+        <source>Installing downloaded files</source>
+        <translation>Instaluji stažené soubory</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="194"/>
+        <source>No downloaded *.debs files found.</source>
+        <translation>Nebyly nalezeny žádné *.deb (instalační) soubory.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="207"/>
+        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
+        <translation>&lt;b&gt;Instaluje se...&lt;/b&gt;&lt;p&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="220"/>
+        <source>Error installing %1</source>
+        <translation>Chyba instalace %1</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="224"/>
+        <source>Fix missing dependencies...</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="226"/>
+        <source>Error running %1 command</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="238"/>
+        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
+        <translation>&lt;b&gt;Instalace dokončena&lt;/b&gt;</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="242"/>
+        <source>Finished</source>
+        <translation>Dokončeno</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="243"/>
+        <source>Codecs files have been downloaded and installed successfully.</source>
+        <translation>Kodeky byly úspěšně staženy a nainstalovány.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="247"/>
+        <source>Process finished. Errors have occurred during the installation.</source>
+        <translation>Proces dokončen. Během instalace se vyskytly chyby. </translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="261"/>
+        <source>About Codecs</source>
+        <translation>O Kodeky</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="262"/>
+        <source>Codecs</source>
+        <translation>Kodeky</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="262"/>
+        <source>Version: </source>
+        <translation>Verze:</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="264"/>
+        <source>Simple codecs downloader for antiX Linux</source>
+        <translation>Jednoduchý instalátor kodeků pro antiX Linux</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="265"/>
+        <source>Copyright (c) MX Linux</source>
+        <translation>Vlastnická práva (c) MX Linux</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="266"/>
+        <source>License</source>
+        <translation>Licence</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="267"/>
+        <location filename="mainwindow.cpp" line="277"/>
+        <source>Changelog</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="285"/>
+        <source>&amp;Close</source>
+        <translation>&amp;Zavřít</translation>
+    </message>
+</context>
 <context>
     <name>QApplication</name>
     <message>
@@ -18,205 +230,4 @@ Prosím nejdřiv ji ukončete</translation>
         <translation>Tuto aplikaci musíte spustit jako root.</translation>
     </message>
 </context>
-<context>
-    <name>codecs</name>
-    <message>
-        <location filename="codecs.ui" line="14"/>
-        <source>Codecs Installer</source>
-        <translation>Instalátor kodeků</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="27"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;Tato aplikace Vám umožní nainstalovat nesvodobné kodeky, které spřístupňují pokročilé funkce videa a audia.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;
-V některých krajinách může byt jejich šíření omezené, je na uživateli, aby dodržoval lokální právné předpisy. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Přebíráte právní zodpovědnost za stažení těchto kodeků?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="44"/>
-        <source>Downloading codecs files</source>
-        <translation>Stahuji kodeky</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="94"/>
-        <source>Cancel any changes then quit</source>
-        <translation>Zrušit všechny změny a ukončit</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="97"/>
-        <location filename="codecs.cpp" line="269"/>
-        <source>Cancel</source>
-        <translation>Zrušit</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="105"/>
-        <source>Alt+N</source>
-        <translation>Alt+N</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="118"/>
-        <source>Apply any changes then quit</source>
-        <translation>Uložit všechny změny a ukončit</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="121"/>
-        <source>OK</source>
-        <translation>OK</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="177"/>
-        <source>About this application</source>
-        <translation>O této aplikaci</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="180"/>
-        <source>About...</source>
-        <translation>O programu</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="188"/>
-        <source>Alt+B</source>
-        <translation>Alt+B</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="217"/>
-        <source>Display help </source>
-        <translation>Zobrazit nápovědu</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="220"/>
-        <source>Help</source>
-        <translation>Nápověda</translation>
-    </message>
-    <message>
-        <location filename="codecs.ui" line="228"/>
-        <source>Alt+H</source>
-        <translation>Alt+H</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="110"/>
-        <location filename="codecs.cpp" line="117"/>
-        <location filename="codecs.cpp" line="125"/>
-        <location filename="codecs.cpp" line="132"/>
-        <location filename="codecs.cpp" line="140"/>
-        <location filename="codecs.cpp" line="147"/>
-        <location filename="codecs.cpp" line="156"/>
-        <location filename="codecs.cpp" line="163"/>
-        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
-        <translation>&lt;b&gt;Spouštím příkaz...&lt;/b&gt;&lt;p&gt;</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="113"/>
-        <location filename="codecs.cpp" line="128"/>
-        <location filename="codecs.cpp" line="134"/>
-        <location filename="codecs.cpp" line="143"/>
-        <location filename="codecs.cpp" line="149"/>
-        <location filename="codecs.cpp" line="159"/>
-        <location filename="codecs.cpp" line="165"/>
-        <location filename="codecs.cpp" line="194"/>
-        <location filename="codecs.cpp" line="246"/>
-        <source>Error</source>
-        <translation>Chyba</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="114"/>
-        <location filename="codecs.cpp" line="129"/>
-        <location filename="codecs.cpp" line="144"/>
-        <location filename="codecs.cpp" line="160"/>
-        <source>Cannot connect to the download site</source>
-        <translation>Nelze se připojit k stránce</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="120"/>
-        <location filename="codecs.cpp" line="135"/>
-        <location filename="codecs.cpp" line="150"/>
-        <location filename="codecs.cpp" line="166"/>
-        <source>Error downloading %1</source>
-        <translation>Chyba stahování %1</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="171"/>
-        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Stahování dokončeno.&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="190"/>
-        <source>Installing downloaded files</source>
-        <translation>Instaluji stažené soubory</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="195"/>
-        <source>No downloaded *.debs files found.</source>
-        <translation>Nebyly nalezeny žádné *.deb (instalační) soubory.</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="211"/>
-        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
-        <translation>&lt;b&gt;Instaluje se...&lt;/b&gt;&lt;p&gt;</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="215"/>
-        <source>Error installing %1</source>
-        <translation>Chyba instalace %1</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="239"/>
-        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Instalace dokončena&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="242"/>
-        <source>Finished</source>
-        <translation>Dokončeno</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="243"/>
-        <source>Codecs files have been downloaded and installed successfully.</source>
-        <translation>Kodeky byly úspěšně staženy a nainstalovány.</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="247"/>
-        <source>Process finished. Errors have occurred during the installation.</source>
-        <translation>Proces dokončen. Během instalace se vyskytly chyby. </translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="262"/>
-        <source>About Codecs</source>
-        <translation>O Kodeky</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="263"/>
-        <source>Codecs</source>
-        <translation>Kodeky</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="263"/>
-        <source>Version: </source>
-        <translation>Verze:</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="265"/>
-        <source>Simple codecs downloader for antiX Linux</source>
-        <translation>Jednoduchý instalátor kodeků pro antiX Linux</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="266"/>
-        <source>Copyright (c) MX Linux</source>
-        <translation>Vlastnická práva (c) MX Linux</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="267"/>
-        <source>License</source>
-        <translation>Licence</translation>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="268"/>
-        <source>Changelog</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="codecs.cpp" line="284"/>
-        <source>&amp;Close</source>
-        <translation>&amp;Zavřít</translation>
-    </message>
-</context>
 </TS>
\ No newline at end of file
